@@ -61,7 +61,6 @@ typedef enum {
 	NAUTILUS_FILE_SORT_BY_TYPE,
 	NAUTILUS_FILE_SORT_BY_MTIME,
         NAUTILUS_FILE_SORT_BY_ATIME,
-	NAUTILUS_FILE_SORT_BY_EMBLEMS,
 	NAUTILUS_FILE_SORT_BY_TRASHED_TIME
 } NautilusFileSortType;	
 
@@ -92,8 +91,6 @@ typedef enum {
 #define NAUTILUS_FILE_EMBLEM_NAME_CANT_WRITE "nowrite"
 #define NAUTILUS_FILE_EMBLEM_NAME_TRASH "trash"
 #define NAUTILUS_FILE_EMBLEM_NAME_NOTE "note"
-#define NAUTILUS_FILE_EMBLEM_NAME_DESKTOP "desktop"
-#define NAUTILUS_FILE_EMBLEM_NAME_SHARED "shared"
 
 typedef void (*NautilusFileCallback)          (NautilusFile  *file,
 				               gpointer       callback_data);
@@ -188,6 +185,8 @@ gboolean                nautilus_file_is_broken_symbolic_link           (Nautilu
 gboolean                nautilus_file_is_nautilus_link                  (NautilusFile                   *file);
 gboolean                nautilus_file_is_executable                     (NautilusFile                   *file);
 gboolean                nautilus_file_is_directory                      (NautilusFile                   *file);
+gboolean                nautilus_file_is_user_special_directory         (NautilusFile                   *file,
+									 GUserDirectory                 special_directory);
 gboolean		nautilus_file_is_archive			(NautilusFile			*file);
 gboolean                nautilus_file_is_in_trash                       (NautilusFile                   *file);
 gboolean                nautilus_file_is_in_desktop                     (NautilusFile                   *file);
@@ -208,8 +207,6 @@ gboolean                nautilus_file_should_show_thumbnail             (Nautilu
 gboolean                nautilus_file_should_show_directory_item_count  (NautilusFile                   *file);
 gboolean                nautilus_file_should_show_type                  (NautilusFile                   *file);
 GList *                 nautilus_file_get_keywords                      (NautilusFile                   *file);
-void                    nautilus_file_set_keywords                      (NautilusFile                   *file,
-									 GList                          *keywords);
 GList *                 nautilus_file_get_emblem_icons                  (NautilusFile                   *file,
 									 char                          **exclude);
 GList *                 nautilus_file_get_emblem_pixbufs                (NautilusFile                   *file,
@@ -390,6 +387,11 @@ gboolean                nautilus_file_matches_uri                       (Nautilu
 gboolean                nautilus_file_is_local                          (NautilusFile                   *file);
 
 /* Comparing two file objects for sorting */
+NautilusFileSortType    nautilus_file_get_default_sort_type             (NautilusFile                   *file,
+									 gboolean                       *reversed);
+const gchar *           nautilus_file_get_default_sort_attribute        (NautilusFile                   *file,
+									 gboolean                       *reversed);
+
 int                     nautilus_file_compare_for_sort                  (NautilusFile                   *file_1,
 									 NautilusFile                   *file_2,
 									 NautilusFileSortType            sort_type,
@@ -414,14 +416,11 @@ int                     nautilus_file_compare_location                  (Nautilu
 
 /* filtering functions for use by various directory views */
 gboolean                nautilus_file_is_hidden_file                    (NautilusFile                   *file);
-gboolean                nautilus_file_is_backup_file                    (NautilusFile                   *file);
 gboolean                nautilus_file_should_show                       (NautilusFile                   *file,
 									 gboolean                        show_hidden,
-									 gboolean                        show_backup,
 									 gboolean                        show_foreign);
-GList                  *nautilus_file_list_filter_hidden_and_backup     (GList                          *files,
-									 gboolean                        show_hidden,
-									 gboolean                        show_backup);
+GList                  *nautilus_file_list_filter_hidden                (GList                          *files,
+									 gboolean                        show_hidden);
 
 
 /* Get the URI that's used when activating the file.
