@@ -55,7 +55,6 @@ struct NautilusSearchDirectoryDetails {
 
 typedef struct {
 	gboolean monitor_hidden_files;
-	gboolean monitor_backup_files;
 	NautilusFileAttributes monitor_attributes;
 
 	gconstpointer client;
@@ -172,7 +171,6 @@ static void
 search_monitor_add (NautilusDirectory *directory,
 		    gconstpointer client,
 		    gboolean monitor_hidden_files,
-		    gboolean monitor_backup_files,
 		    NautilusFileAttributes file_attributes,
 		    NautilusDirectoryCallback callback,
 		    gpointer callback_data)
@@ -186,7 +184,6 @@ search_monitor_add (NautilusDirectory *directory,
 
 	monitor = g_new0 (SearchMonitor, 1);
 	monitor->monitor_hidden_files = monitor_hidden_files;
-	monitor->monitor_backup_files = monitor_backup_files;
 	monitor->monitor_attributes = file_attributes;
 	monitor->client = client;
 
